@@ -7,7 +7,7 @@ use Moops;
 
 class Pod::Weaver::Section::Badges using Moose with Pod::Weaver::Role::Section {
 
-    our $VERSION = '0.0100'; # VERSION
+    our $VERSION = '0.0101'; # VERSION
     # ABSTRACT: Insert badges in your pod
     use MooseX::AttributeDocumented;
 
@@ -174,7 +174,7 @@ Pod::Weaver::Section::Badges - Insert badges in your pod
 
 =head1 VERSION
 
-Version 0.0100, released 2015-02-14.
+Version 0.0101, released 2015-02-15.
 
 
 
@@ -339,16 +339,20 @@ This inserts a section with status badges. The configuration in the synopsis wou
 
 =end HTML
 
+=head1 NOTE
+
+Planned api changes: Badges will in the near future be created as plugins to this class.
+
 =head1 SEE ALSO
 
 =over 4
 
+=item *
 
+L<Dist::Zilla::Plugin::TravisCI::StatusBadge>
 
 =back
 
-* Dist::Zilla::Plugin::TravisCI::StatusBadge
-
 =head1 BUILD STATUS
 
 =for HTML <p><a href="https://travis-ci.org/Csson/p5-Pod-Weaver-Section-Badges"><img src="https://travis-ci.org/Csson/p5-Pod-Weaver-Section-Badges.svg?branch=master" /></a></p>
